cd "/Users/morganhazelton/Dropbox/CurrentProjects/BriefsBook/ReplicationFiles/"

cd "/Users/rachaelhinkle/Dropbox/BriefsBook/ReplicationFiles/"


*** Figure 1.1
use "Data/Florida_v_Harris.dta", clear
tabstat WC counter totalCites coSignors totPrevExp numAttys totAttyExp, by(petSide) stat(sum)
tabstat smog , by(petSide) stat(mean)

*** Table 1.1 
use "Data/brief_level.dta", clear
tab briefType

**As discussed in appendix B, the source of these briefs is as follows
tab source

*** Figure 1.2
use "Data/brief_level.dta", clear
drop if reply == 1

egen yearTot = sum(counter), by(term)
egen yearTotA = sum(amicus), by(term)
gen yearTotP = yearTot - yearTotA
keep yearTot yearTotA yearTotP term 
duplicates drop

twoway (line yearTotP yearTotA term, lwidth(medthick) xscale(range(1985 2015)) xtick(1985(5)2015) xlab(1985(5)2015) lpattern(solid shortdash)), scheme(s1mono) xtitle("Term") ytitle("Number of Briefs") title("") legend(order(1 "Litigant" 2 "Amicus" )) 

tab yearTotA if term == 2012
tab yearTotA if term == 2001

regress yearTotA term if term > 1993
regress yearTotP term if term > 1993


*** Figure 1.3

** Top panel: Filers
use "Data/brief_filer_level.dta", clear
drop if term < 1984

egen yearTot = sum(counter), by(term)
egen yearTotA = sum(amicus), by(term)
gen yearTotP = yearTot - yearTotA
keep yearTot yearTotA yearTotP term briefID amicus
duplicates drop

gen counter = 1
egen yearTotBr = sum(counter), by(term)
egen yearTotBrA = sum(amicus), by(term)
gen yearTotBrP = yearTotBr - yearTotBrA

keep yearTot* term 
duplicates drop

gen yearTotArate = yearTotA/yearTotBrA
gen yearTotPrate = yearTotP/yearTotBrP

regress yearTotPrate term
regress yearTotArate term

sum yearTotPrate
sum yearTotArate

twoway (line yearTotPrate yearTotArate term, lwidth(medthick) yscale(range(0 10)) ytick(0(1)10) ylab(0(2)10) xscale(range(1985 2015)) xtick(1985(5)2015) xlab(1985(5)2015) lpattern(solid shortdash)), scheme(s1mono) xtitle("Term") ytitle("Number of Filers per Brief") title("") legend(order(1 "Litigant" 2 "Amicus" )) 


** Bottom panel: Attorneys
use "Data/brief_atty_level.dta", clear
drop if term < 1984
drop if briefType == "petitioner reply"

egen yearTot = sum(counter), by(term)
egen yearTotA = sum(amicus), by(term)
gen yearTotP = yearTot - yearTotA

keep yearTot yearTotA yearTotP term briefID counter amicus 
duplicates drop

egen yearTotBrA = sum(counter) if amicus == 1, by(term)
egen yearTotBrP = sum(counter) if amicus == 0, by(term)

gen yearTotArate = yearTotA/yearTotBrA
gen yearTotPrate = yearTotP/yearTotBrP

regress yearTotPrate term
sum yearTotPrate if term == 1984
sum yearTotPrate if term == 2015

sort term
twoway (line yearTotPrate yearTotArate term, lwidth(medthick) yscale(range(0 10)) ytick(0(1)10) ylab(0(2)10) xscale(range(1985 2015)) xtick(1985(5)2015) xlab(1985(5)2015) lpattern(solid shortdash)), scheme(s1mono) xtitle("Term") ytitle("Number of Attorneys per Brief") title("") legend(order(1 "Litigant" 2 "Amicus" )) 


*** Figure 1.4
use "Data/brief_level.dta", clear
drop if reply == 1

kdensity WC if amicus == 0, lwidth(medthick) scheme(s1mono) title("Litigant Briefs") xtitle("Word Count") xline(15000)
kdensity WC if amicus == 1, lwidth(medthick) scheme(s1mono) title("Amicus Briefs") xtitle("Word Count") xline(9000)

count if amicus == 0
count if amicus == 0 & WC > 15000
di 1626 / 6252
count if amicus == 0 & WC > 15100
di 1544 / 6252

count if amicus == 1
count if amicus == 1 & WC > 9000
di 2926 / 16962
count if amicus == 1 & WC > 9100
di 2629 / 16962

sum WC if amicus == 0
sum WC if amicus == 1


***FN 8 robustness check: "briefs that exceed the word limit have a slightly lower chance of both being on the winning side and having their language appear in the majority opinion."
use "Data/brief_level.dta", clear
drop if reply == 1
gen overLimit = 0
replace overLimit = 1 if amicus == 0 & WC > 15000
replace overLimit = 1 if amicus == 1 & WC > 9000

gen excessWords = WC - 15000 if amicus == 0
replace excessWords = WC - 9000 if amicus == 1
replace excessWords = 0 if excessWords < 0

* Winning the case
probit sideWon overLimit amicus, robust cluster(caseLexCite)
probit sideWon excessWords amicus, robust cluster(caseLexCite)

*To do the robustness check for similarity to the majority opinion, we use our model from Chapter 5
glm simToMajOpin overLimit, link(logit) family(binomial) 
glm simToMajOpin excessWords, link(logit) family(binomial) robust cluster(caseLexCite)

use "Data/brief_level.dta", clear
drop if briefType == "amicus for neither party"
drop if term < 1984
drop if reply == 1
drop if WC_LCopin == .
drop if medAligned == .
drop if rawQuestions == .

glm simToMajOpin overLimit amicus tfidf_norm_50_1000 cfidf_norm_50 uWCK totalUCites100 dupWCK dupTotalCites simToLCOpin  numBriefs  totMedCites techLang future smog emoLang logCoSignors logNumAttys logMaxFilExp logMaxAttyExp totClerks totPastSG currentSG petSide medAligned logWC_LCOpin amicusLC rawQuestions term, link(logit) family(binomial) robust cluster(caseLexCite)
glm simToMajOpin excessWords amicus tfidf_norm_50_1000 cfidf_norm_50 uWCK totalUCites100 dupWCK dupTotalCites simToLCOpin  numBriefs  totMedCites techLang future smog emoLang logCoSignors logNumAttys logMaxFilExp logMaxAttyExp totClerks totPastSG currentSG petSide medAligned logWC_LCOpin amicusLC rawQuestions term, link(logit) family(binomial) robust cluster(caseLexCite)


*** FN 9
sum WC if amicus == 0
sum WC if amicus == 1



*** Figure 1.5
use "Data/brief_level.dta", clear
drop if reply == 1
kdensity totalCites if amicus == 0, lwidth(medthick) scheme(s1mono) title("") xtitle("Total Citations") addplot(kdensity totalCites if amicus == 1, lpattern(shortdash)) legend(order(1 "Litigant Briefs" 2 "Amicus Briefs" ) rows(1))  



*** Figure 1.6 and FN 11
use "Data/brief_level.dta", clear
drop if reply == 1
regress totalCites term if amicus == 1 & term >=2000
regress totalCites term if amicus == 0 & term >=2000

egen yearCitesparty = mean(totalCites) if amicus == 0, by(term)
egen yearCitesamicus = mean(totalCites) if amicus == 1, by(term)

sort term
twoway (line yearCitesparty yearCitesamicus term, lwidth(medthick) xscale(range(1985 2015)) xtick(1985(5)2015) xlab(1985(5)2015) yscale(range(0 80)) ytick(0(10)80) ylab(0(20)80) lpattern(solid shortdash)), scheme(s1mono) xtitle("Term") ytitle("Mean Cites per Brief") title("") legend(order(1 "Litigant" 2 "Amicus" ))  


*** Figure 1.7 and FN 12
use "Data/brief_level.dta", clear
drop if reply == 1
sum fkgl cli fog smog ari 

sum smog if term > 2005
sum smog if term < 2005

egen yearSMOGparty = mean(smog) if amicus == 0, by(term)
egen yearSMOGamicus = mean(smog) if amicus == 1, by(term)

sort term
twoway (line yearSMOGparty yearSMOGamicus term, lwidth(medthick) xscale(range(1985 2015)) xtick(1985(5)2015) xlab(1985(5)2015) yscale(range(10 20)) ytick(10(1)20) ylab(10(2)20) lpattern(solid shortdash)), scheme(s1mono) xtitle("Term") ytitle("Grade Level") title("") legend(order(1 "Litigant" 2 "Amicus" ))  


*** Figure 1.8 
use "Data/brief_level.dta", clear
drop if reply == 1

egen yearEmoP = mean(emoLang) if amicus == 0, by(term)
egen yearEmoA = mean(emoLang) if amicus == 1, by(term)

twoway (line yearEmoP yearEmoA term, lwidth(medthick) xscale(range(1985 2015)) xtick(1985(5)2015) xlab(1985(5)2015) yscale(range(1 9)) ytick(1(1)9) ylab(1(1)9) lpattern(solid shortdash)), scheme(s1mono) xtitle("Term") ytitle("Mean % Emotional Language") title("") legend(order(1 "Litigant" 2 "Amicus" ))  


*** Figure 1.9 
use "Data/brief_filer_level.dta", clear
drop if generic == 1

gen counter2 =0
replace counter2 = 1 if term >= 1984
egen totFiler = sum(counter), by(filerID)
egen post83 = sum(counter2), by(filerID)
keep term counter amicus filerID type tot* post83 
duplicates drop

gen oneShot = 0
replace oneShot = 1 if totFiler == 1
gen repeat = 0
replace repeat = 1 if totFiler > 1
drop if post83 == 0

tab type
tab type repeat, row

graph hbar (sum) oneShot repeat, over(type) stack scheme(s1manual) legend(lab(1 "One-time Filers") lab(2 "Repeat Filers"))ytitle("Unique Filers by Type")


*** Figure 1.10
use "Data/brief_level.dta", clear
drop if briefType == "petitioner reply"

egen totAmic = sum(counter) if amicus == 1, by(type)
egen totParty = sum(counter) if amicus == 0, by(type)
keep  type totAmic totParty
duplicates drop

graph  hbar (sum) totParty, over(type) scheme(s1manual) yscale(range(0 12000)) ytick(0(1000)12000) ylab(0(2000)12000) ytitle("Overall Participation by Type - Party Briefs")
graph  hbar (sum) totAmic, over(type) scheme(s1manual) yscale(range(0 12000)) ytick(0(1000)12000) ylab(0(2000)12000) ytitle("Overall Participation by Type - Amicus Briefs")


*** Table 1.2
use "Data/brief_filer_level.dta", clear
drop if term < 1984
drop if briefType == "petitioner reply"
egen totFiler = sum(counter), by(filerID)

keep filerID filer totFiler interestGroup
duplicates drop
gsort -totFiler
list filer totFiler if interestGroup == 1 & _n < 61


*** Figure 1.11
use "Data/brief_filer_level.dta", clear
drop if term < 1984
drop if briefType == "petitioner reply"

egen yearTot = sum(counter), by(type term)
egen yearTotA = sum(amicus), by(type term)
gen yearTotP = yearTot - yearTotA
keep yearTot yearTotA yearTotP term type
duplicates drop

reshape wide yearTot yearTotA yearTotP, i(term) j(type) 

regress yearTotP1 term
regress yearTotP2 term
regress yearTotP3 term
regress yearTotP4 term
regress yearTotP5 term

twoway (line yearTotP1 yearTotP2 yearTotP3 yearTotP4  yearTotP5 term, lwidth(medthick) xscale(range(1985 2015)) xtick(1985(5)2015) xlab(1985(5)2015) lpattern(shortdash dash solid shortdash dash )), scheme(s1color) xtitle("Term") ytitle("Number of Party Filers By Type") legend(order(1 "Individual" 2 "Business" 3 "Interest Group" 4 "Subnational Govt." 5 "National Govt.")) 

regress yearTotA1 term
regress yearTotA2 term
regress yearTotA3 term
regress yearTotA4 term
regress yearTotA5 term

twoway (line yearTotA1 yearTotA2 yearTotA3 yearTotA4  yearTotA5 term, lwidth(medthick) xscale(range(1985 2015)) xtick(1985(5)2015) xlab(1985(5)2015) lpattern(shortdash dash solid  shortdash dash )), scheme(s1color) xtitle("Term") ytitle("Number of Amicus Filers By Type") legend(order(1 "Individual" 2 "Business" 3 "Interest Group" 4 "Subnational Govt." 5 "National Govt.")) 


*** Figure 1.13
use "Data/brief_atty_level.dta", clear

gen counter2 = 0
replace counter2 = 1 if term > 1983

egen totBriefs = sum(counter), by(attyID)
egen post83 = sum(counter2), by(attyID)
keep  attyID totBriefs post83 attyName
duplicates drop attyID totBriefs post83, force

gen oneShot = 0
replace oneShot = 1 if totBriefs == 1

gen repeat = 0
replace repeat = 1 if totBriefs > 1

drop if post83 == 0

graph bar (count), over(oneShot, relabel(1 "Repeat Attorneys" 2 "One-Time Attorneys")) scheme(s1manual) ytitle("Unique Attorneys")

tab oneShot

count if totBriefs >= 100
sum totBriefs if oneShot == 0, detail



*** Table 1.3
gsort -totBriefs
list attyName totBriefs if _n < 11



*** Figure 1.14
use "Data/brief_atty_level.dta", clear
drop if term < 1984
drop if briefType == "petitioner reply"

egen yearExpAtty = median(numAppear), by(attyID term)
keep yearExpAtty term amicus attyID
duplicates drop

egen yearMeanExpP = mean(yearExpAtty) if amicus == 0, by(term)
egen yearMeanExpA = mean(yearExpAtty) if amicus == 1, by(term)

regress yearMeanExpA term
regress yearMeanExpP term

sort term
twoway (line yearMeanExpP yearMeanExpA term, lwidth(medthick) yscale(range(0 20)) ytick(0(5)20) ylab(0(5)20) xscale(range(1985 2015)) xtick(1985(5)2015) xlab(1985(5)2015) lpattern(solid shortdash)), scheme(s1mono) xtitle("Term") ytitle("Average Experience of Individual Attorneys") legend(order(1 "Parties" 2 "Amici")) 


** Clerks and former SGs
use "Data/brief_atty_level.dta", clear
drop if briefType == "petitioner reply"
drop if term < 1984
tab clerk
tab pastSG

keep attyID clerk pastSG
duplicates drop
tab clerk
tab pastSG

use "Data/brief_level.dta", clear
drop if briefType == "petitioner reply"
drop if term < 1984

tab anyClerks
tab pastSG

