cd "/Users/morganhazelton/Dropbox/CurrentProjects/BriefsBook/ReplicationFiles/"

cd "/Users/rachaelhinkle/Dropbox/BriefsBook/ReplicationFiles/"

***Summary statistics from Florida v. Harris discussed in the Introduction
use "Data/brief_level.dta", clear
keep if caseLexCite == "2013 U.S. LEXIS 1121"

*Party briefs were longest
*Florida's brief over 11K words
*Harris's brief 209 words under 15000
gsort -WC
list WC briefType
di 15000-209
*Florida's attorneys 165 previous briefs
list totAttyExp if briefType == "petitioner"
*Harris's attorneys 0 previous briefs
list totAttyExp if briefType == "respondent"

*5 amicus briefs for Harris (see above)
*Amcius briefs ranged in length from 4,363 to 9,606 (see above)

*Virginia et al. had 33 attorneys with more than 1,200. The total previous experience was more than 7,000 briefs 
list numAttys totAttyExp totPrevExp if amicus == 1 & state == 1
*2 amicus briefs had one attorney with no previous experience
count if numAttys == 1 & amicus == 1
count if totAttyExp == 0 & amicus == 1

*Florida had 361 previous briefs
list totPrevExp if briefType == "petitioner"
*Harris had no previous briefs
list totPrevExp if briefType == "respondent"



use "Data/brief_level.dta", clear
*** Drop the following briefs from analysis
drop if briefType == "amicus for neither party"
*** Drop the early years of the data to provide a "burn-in" period for experience measures
drop if term < 1984
*** Drop reply briefs
drop if reply == 1
*** Drop if lower court opinion not available
drop if WC_LCopin == . | WC_LCopin == 0
*** Drop if ideological direction of ruling not specified
drop if medAligned == .


** FN 3, 69% of federal govt. briefs signed by SG
tab currentSG if status == 4

*** FN 7 Code provided at the end of this file (because it requires loading a new dataset) 

*** FN 9 Code provided after main  models (because comparison to those models is necessary)

*** FN 14: Creating a variable with an overall summary of information quantity 
factor logWC docVocab totalCites precVocab 
screeplot
predict quantity_factor
replace quantity_factor = quantity_factor*10
label variable quantity_factor "Quantity of Information"

*** Table 2.1: Summary Statistics
eststo sumstats: estpost summarize quantity_factor totMedCites techLang future emoLang smog logCoSignors logNumAttys logMaxPrevExp logMaxAttyExp totClerks totPastSG  medAligned logWC_LCOpin term, d
estout sumstats, cells("min(fmt(2)) p25(fmt(2)) p50(fmt(2)) p75(fmt(2)) max(fmt(2))") label 

tab status
tab currentSG
tab briefByInvite
tab petSide
tab amicusLC

**** Main Models

*** Quantity of Information
regress quantity_factor b2.status logCoSignors logNumAttys logMaxPrevExp logMaxAttyExp totClerks totPastSG currentSG  petSide medAligned logWC_LCOpin amicusLC term if party == 1 & reply == 0, robust cluster(caseLexCite)
estimates store modpQ
regress quantity_factor b2.status logCoSignors logNumAttys logMaxPrevExp logMaxAttyExp totClerks totPastSG currentSG briefByInvite petSide medAligned logWC_LCOpin amicusLC term if amicus == 1 , robust cluster(caseLexCite)
estimates store modaQ
***Figure 2.1 (and Table A1)
estout modpQ modaQ , cells(b(star fmt(3)) se(fmt(3) par)) starlevels(* 0.05) stats( N r2 bic) label varlabels(_cons Intercept)

*Moving from two attorneys to five (1.10 to 1.79 when logged)
*Note: Because the log of zero is undefined, all of our logged measures are the natural log of the relevant quantity + 1
**     For example, the log of experience for an attorney with zero prior briefs is ln(1) = 0.00 and for one prior brief is ln(2) = 0.69
di (1.79-1.10)*3.513
sum quantity_factor
di 2.4/9.67

*Each clerk adds 1.1 for amicus (the coef. from the model)
*Invited amicus briefs add 3.5 (the coef. from the model)

*** Strategic Information
regress totMedCites b2.status logCoSignors logNumAttys logMaxPrevExp logMaxAttyExp totClerks totPastSG currentSG  petSide medAligned logWC_LCOpin amicusLC term if party == 1 & reply == 0, robust cluster(caseLexCite)
estimates store modpS1
regress totMedCites b2.status logCoSignors logNumAttys logMaxPrevExp logMaxAttyExp totClerks totPastSG currentSG briefByInvite petSide medAligned logWC_LCOpin amicusLC term if amicus == 1 , robust cluster(caseLexCite)
estimates store modaS1
***Figure 2.2 (and Table A2)
estout modpS1 modaS1, cells(b(star fmt(3)) se(fmt(3) par)) starlevels(* 0.05) stats( N r2 bic) label varlabels(_cons Intercept) 

* moving atty exp for a party brief from 75th (4.06) to 25th (1.1) increases by 0.8
di (4.06-1.1)*0.279
* average number of strategic cites is 2.5
sum totMedCites


*** Type of Information
** Figure 2.3: The briefs and LIWC analysis for this figure are availalbe form the authors on request

** Technical Language
regress techLang b2.status logCoSignors logNumAttys logMaxPrevExp logMaxAttyExp totClerks totPastSG currentSG  petSide medAligned logWC_LCOpin amicusLC term if party == 1 & reply == 0, robust cluster(caseLexCite)
estimates store modp3
regress techLang b2.status logCoSignors logNumAttys logMaxPrevExp logMaxAttyExp totClerks totPastSG currentSG briefByInvite petSide medAligned logWC_LCOpin amicusLC term if amicus == 1 , robust cluster(caseLexCite)
estimates store moda3
** Future Language
regress future b2.status logCoSignors logNumAttys logMaxPrevExp logMaxAttyExp totClerks totPastSG currentSG  petSide medAligned logWC_LCOpin amicusLC term if party == 1 & reply == 0, robust cluster(caseLexCite)
estimates store modp3b
regress future b2.status logCoSignors logNumAttys logMaxPrevExp logMaxAttyExp totClerks totPastSG currentSG briefByInvite petSide medAligned logWC_LCOpin amicusLC term if amicus == 1 , robust cluster(caseLexCite)
estimates store moda3b
***Figure 2.3 (and Table A3)
estout modp3 moda3 modp3b moda3b, cells(b(star fmt(3)) se(fmt(3) par)) starlevels(* 0.05) stats( N r2 bic) label varlabels(_cons Intercept)

* Moving from two attorenys to five (1.10 to 1.79 when logged) increases tech info by 0.25 for parties and 0.15 for amici
di (1.79-1.10)* 0.359
di (1.79-1.10)* 0.211

* Average tech info is 7.76 with sd of 1.76
sum techLang

* Each clerk adds 0.01 future language  (the coef. from the model) fix specification of which model (it's 0.01 for parties and 0.02 for amici)
* that is 1/3 of a sd (fix, it's 3% of a sd) and mean future language is only 0.87),
sum future
di 0.01/0.28

*** Presentation Style
** Emotional Language
regress emoLang b2.status logCoSignors logNumAttys logMaxPrevExp logMaxAttyExp totClerks totPastSG currentSG petSide medAligned logWC_LCOpin amicusLC term if party == 1 & reply == 0, robust cluster(caseLexCite)
estimates store modp4
regress emoLang b2.status logCoSignors logNumAttys logMaxPrevExp logMaxAttyExp totClerks totPastSG currentSG briefByInvite petSide medAligned logWC_LCOpin amicusLC term if amicus == 1 , robust cluster(caseLexCite)
estimates store moda4
** Readability
regress smog b2.status logCoSignors logNumAttys logMaxPrevExp logMaxAttyExp totClerks totPastSG currentSG petSide medAligned logWC_LCOpin amicusLC term if party == 1 & reply == 0, robust cluster(caseLexCite)
estimates store modp5
regress smog b2.status logCoSignors logNumAttys logMaxPrevExp logMaxAttyExp totClerks totPastSG currentSG briefByInvite petSide medAligned logWC_LCOpin amicusLC term if amicus == 1 , robust cluster(caseLexCite)
estimates store moda5
***Figure 2.5 (and Table A4)
estout modp4 moda4 modp5 moda5, cells(b(star fmt(3)) se(fmt(3) par)) starlevels(* 0.05) stats( N r2 bic) label varlabels(_cons Intercept) 

* Moving from 2 to 5 attorneys (1.10 to 1.79 when logged) for amicus briefs reduced emo lang by 0.02
di (1.79-1.10)*0.032

* Average emo lang is 3.0 with a sd of 0.92
sum emoLang

* Moving from 1 to 2 (0.69 to 1.10 when logged) cosigners on an amicus brief increases emo lang by 0.03
di (1.10-0.69)*0.082

* Average grade levl is 17 and sd is a grade and a half
sum smog

* Each clerk increases grade level by 0.06 (the coef. from the models)

* Moving from 2 to 5 attorneys (1.10 to 1.79 when logged) on an amicus brief decreases by 0.06 grades
di (1.79-1.10)*0.089



*** Robustness checks discussed in footnotes 9 and 22
 
**FN 9: Using average attorney experience produces very similar results (as using maximum attorney experience)

** Quantity of Information
regress quantity_factor b2.status logCoSignors logNumAttys logMaxPrevExp logMeanAttyExp totClerks totPastSG currentSG  petSide medAligned logWC_LCOpin amicusLC term if party == 1 & reply == 0, robust cluster(caseLexCite)
estimates store modpQc
regress quantity_factor b2.status logCoSignors logNumAttys logMaxPrevExp logMeanAttyExp totClerks totPastSG currentSG briefByInvite petSide medAligned logWC_LCOpin amicusLC term if amicus == 1 , robust cluster(caseLexCite)
estimates store modaQc
estout modpQ modpQc, cells(b(star fmt(3)) se(fmt(3) par)) starlevels(* 0.05) stats( N r2 bic) label varlabels(_cons Intercept) 
estout modaQ modaQc, cells(b(star fmt(3)) se(fmt(3) par)) starlevels(* 0.05) stats( N r2 bic) label varlabels(_cons Intercept) 

** Strategic Information
regress totMedCites b2.status logCoSignors logNumAttys logMaxPrevExp logMeanAttyExp totClerks totPastSG currentSG  petSide medAligned logWC_LCOpin amicusLC term if party == 1 & reply == 0, robust cluster(caseLexCite)
estimates store modpS1c
regress totMedCites b2.status logCoSignors logNumAttys logMaxPrevExp logMeanAttyExp totClerks totPastSG currentSG briefByInvite petSide medAligned logWC_LCOpin amicusLC term if amicus == 1 , robust cluster(caseLexCite)
estimates store modaS1c
estout modpS1 modpS1c, cells(b(star fmt(3)) se(fmt(3) par)) starlevels(* 0.05) stats( N r2 bic) label varlabels(_cons Intercept) 
estout modaS1 modaS1c, cells(b(star fmt(3)) se(fmt(3) par)) starlevels(* 0.05) stats( N r2 bic) label varlabels(_cons Intercept) 

** Technical Language
regress techLang b2.status logCoSignors logNumAttys logMaxPrevExp logMeanAttyExp totClerks totPastSG currentSG petSide medAligned logWC_LCOpin amicusLC term if party == 1 & reply == 0, robust cluster(caseLexCite)
estimates store modp3c
regress techLang b2.status logCoSignors logNumAttys logMaxPrevExp logMeanAttyExp totClerks totPastSG currentSG briefByInvite petSide medAligned logWC_LCOpin amicusLC term if amicus == 1 , robust cluster(caseLexCite)
estimates store moda3c

** Future Language
regress future b2.status logCoSignors logNumAttys logMaxPrevExp logMeanAttyExp totClerks totPastSG currentSG  petSide medAligned logWC_LCOpin amicusLC term if party == 1 & reply == 0, robust cluster(caseLexCite)
estimates store modp3bc
regress future b2.status logCoSignors logNumAttys logMaxPrevExp logMeanAttyExp totClerks totPastSG currentSG briefByInvite petSide medAligned logWC_LCOpin amicusLC term if amicus == 1 , robust cluster(caseLexCite)
estimates store moda3bc

estout modp3 modp3c modp3b modp3bc, cells(b(star fmt(3)) se(fmt(3) par)) starlevels(* 0.05) stats( N r2 bic) label varlabels(_cons Intercept) 
estout moda3 moda3c moda3b moda3bc, cells(b(star fmt(3)) se(fmt(3) par)) starlevels(* 0.05) stats( N r2 bic) label varlabels(_cons Intercept) 

** Emotional Langugae
regress emoLang b2.status logCoSignors logNumAttys logMaxPrevExp logMeanAttyExp totClerks totPastSG currentSG  petSide medAligned logWC_LCOpin amicusLC term if party == 1 & reply == 0, robust cluster(caseLexCite)
estimates store modp4c
regress emoLang b2.status logCoSignors logNumAttys logMaxPrevExp logMeanAttyExp totClerks totPastSG currentSG briefByInvite petSide medAligned logWC_LCOpin amicusLC term if amicus == 1 , robust cluster(caseLexCite)
estimates store moda4c

** Readability
regress smog b2.status logCoSignors logNumAttys logMaxPrevExp logMeanAttyExp totClerks totPastSG currentSG  petSide medAligned logWC_LCOpin amicusLC term if party == 1 & reply == 0, robust cluster(caseLexCite)
estimates store modp5c
regress smog b2.status logCoSignors logNumAttys logMaxPrevExp logMeanAttyExp totClerks totPastSG currentSG briefByInvite petSide medAligned logWC_LCOpin amicusLC term if amicus == 1 , robust cluster(caseLexCite)
estimates store moda5c

estout modp4 modp4c modp5 modp5c, cells(b(star fmt(3)) se(fmt(3) par)) starlevels(* 0.05) stats( N r2 bic) label varlabels(_cons Intercept) 
estout moda4 moda4c moda5 moda5c, cells(b(star fmt(3)) se(fmt(3) par)) starlevels(* 0.05) stats( N r2 bic) label varlabels(_cons Intercept) 



** FN 22: Same significant results found if we use a composite meaure of readability
* Note: Composite measure is scaled in the opposite direction so results from two models have opposite signs
regress readability b2.status logCoSignors logNumAttys logMaxPrevExp logMaxAttyExp totClerks totPastSG currentSG petSide medAligned logWC_LCOpin amicusLC term if party == 1 & reply == 0, robust cluster(caseLexCite)
estimates store modp5b
regress readability b2.status logCoSignors logNumAttys logMaxPrevExp logMaxAttyExp totClerks totPastSG currentSG briefByInvite petSide medAligned logWC_LCOpin amicusLC term if amicus == 1 , robust cluster(caseLexCite)
estimates store moda5b
estout modp5 modp5b, cells(b(star fmt(3)) se(fmt(3) par)) starlevels(* 0.05) stats( N r2 bic) label varlabels(_cons Intercept) style(fixed)
estout moda5 moda5b, cells(b(star fmt(3)) se(fmt(3) par)) starlevels(* 0.05) stats( N r2 bic) label varlabels(_cons Intercept) style(fixed)



*** FN 7 Data has more than 23,000 distinct filing entities
use "Data/brief_filer_level.dta", clear
drop if term < 1984
keep filerID
duplicates drop
count
